import { TypeKeys } from "web-utility";
import { IDType, DataObject, NewData, Filter, ListModel } from "mobx-restful";
export interface StrapiDataItem<A extends DataObject, M extends DataObject = DataObject> {
    id: number;
    attributes: StrapiNestedData<A>;
    meta: M;
}
export interface StrapiItemWrapper<A extends DataObject, M extends DataObject = DataObject> {
    data: StrapiDataItem<A>;
    meta?: M;
}
export interface StrapiListWrapper<A extends DataObject> {
    data: StrapiDataItem<A>[];
    meta?: {
        pagination: Record<'page' | 'pageSize' | 'pageCount' | 'total', number>;
    };
}
export type StrapiNestedData<T extends DataObject> = {
    [K in keyof T]: T[K] extends DataObject[] ? StrapiListWrapper<T[K]> : T[K] extends DataObject ? StrapiItemWrapper<T[K]> : T[K];
};
export type StrapiPopulateQuery<D extends DataObject> = {
    [K in TypeKeys<D, DataObject | DataObject[]>]?: {
        populate: '*' | (Required<D>[K] extends (infer I)[] ? TypeKeys<I, DataObject | DataObject[]> : TypeKeys<Required<D>[K], DataObject>);
    };
};
export abstract class StrapiListModel<D extends DataObject, F extends Filter<D> = Filter<D>> extends ListModel<D, F> {
    populate: StrapiPopulateQuery<D>;
    searchKeys: Exclude<TypeKeys<D, string>, this['indexKey']>[];
    accessor keywords: string;
    get searchFilter(): {
        $or: Record<Exclude<TypeKeys<D, string>, keyof D>, {
            $containsi: string;
        }>[];
    };
    protected normalize({ id, attributes }: StrapiDataItem<D>): {
        id: number;
    } & D;
    getOne(id: IDType): Promise<{
        id: number;
    } & D>;
    updateOne(data: NewData<D>, id?: IDType): Promise<{
        id: number;
    } & D>;
    makeFilter(pageIndex: number, pageSize: number, filter: F): {
        populate: StrapiPopulateQuery<D>;
        filters: {
            $or: Record<Exclude<TypeKeys<D, string>, keyof D>, {
                $containsi: string;
            }>[];
        } | Record<string, {
            $eq: any;
        }>;
        pagination: {
            page: number;
            pageSize: number;
        };
    };
    loadPage(pageIndex: number, pageSize: number, filter: F): Promise<{
        pageData: ({
            id: number;
        } & D)[];
        totalCount: number;
    }>;
    search(keywords: string, pageIndex: number, pageSize: number): Promise<D[]>;
}

//# sourceMappingURL=index.d.ts.map
